@@ -1,4 +1,5 @@
+#TTTARS for replicated study
 RepTTTARS<-function(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1){
  TTTARS(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1,
-              separateWindows=TRUE,Demo=FALSE, BANOVA=FALSE,replicated=TRUE, MIX=FALSE)
+              separateWindows=TRUE,Demo=FALSE, BANOVA=FALSE,replicated=TRUE, MIX=FALSE,parallel=FALSE)
 }
\ No newline at end of file
